@@ -18,6 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "mediastreamer2/msfilter.h"
+#include "mediastreamer2/msticker.h"
 
 #include <speex/speex.h>
 
@@ -303,7 +304,7 @@ static int enc_add_fmtp(MSFilter *f, void *arg){
 		s->mode=atoi(buf);
 	}
 	else {
-		s->mode = -1; /* deault mode */
+		s->mode = -1; /* default mode */
 	}
 	return 0;
 }
@@ -389,11 +390,16 @@ MSFilterDesc ms_speex_enc_desc={
 
 #endif
 
+static const int plc_max=10;/*10 frames of plc, no more*/
+
 typedef struct DecState{
 	int rate;
 	int penh;
 	int frsz;
+	uint64_t sample_time;
 	void *state;
+	int plc_count;
+	bool_t plc;
 } DecState;
 
 static void dec_init(MSFilter *f){
@@ -402,6 +408,9 @@ static void dec_init(MSFilter *f){
 	s->frsz=0;
 	s->state=NULL;
 	s->penh=1;
+	s->sample_time=0;
+	s->plc=1;
+	s->plc_count=0;
 	f->data=s;
 }
 
@@ -439,6 +448,7 @@ static void dec_preprocess(MSFilter *f){
 	speex_mode_query(mode,SPEEX_MODE_FRAME_SIZE,&s->frsz);
 	if (s->penh==1)
 		speex_decoder_ctl (s->state, SPEEX_SET_ENH, &s->penh);
+	s->sample_time=0;
 }
 
 static void dec_postprocess(MSFilter *f){
@@ -453,46 +463,80 @@ static int dec_set_sr(MSFilter *f, void *arg){
 	return 0;
 }
 
+int dec_add_fmtp(MSFilter *f, void *arg){
+	DecState *s=(DecState*)f->data;
+	const char *fmtp=(const char *)arg;
+	char buf[32];
+	if (fmtp_get_value(fmtp, "plc", buf, sizeof(buf))){
+		s->plc=atoi(buf);
+	}
+	return 0;
+}
+
 static void dec_process(MSFilter *f){
 	DecState *s=(DecState*)f->data;
 	mblk_t *im;
 	mblk_t *om;
-	int err;
-	int frame_per_packet;
+	int err=-2;
 	SpeexBits bits;
 	int bytes=s->frsz*2;
-	speex_bits_init(&bits);
+	bool_t bits_initd=FALSE;
+	
 	while((im=ms_queue_get(f->inputs[0]))!=NULL){
-		speex_bits_reset(&bits);
+		int rem_bits=(im->b_wptr-im->b_rptr)*8;
+		
+		if (!bits_initd) {
+			speex_bits_init(&bits);
+			bits_initd=TRUE;
+		}else speex_bits_reset(&bits);
+
 		speex_bits_read_from(&bits,(char*)im->b_rptr,im->b_wptr-im->b_rptr);
-		om=allocb(bytes*7,0);
-		/* support for multiple frame (max=7 frames???) in one RTP packet */
-        for (frame_per_packet=0;frame_per_packet<7;frame_per_packet++)
-        {
-            int i;
-			err=speex_decode_int(s->state,&bits,(int16_t*)(om->b_wptr+(frame_per_packet*320)));
-            
-            i = speex_bits_remaining(&bits);
-			if (i<10) /* this seems to work: don't know why. */
-                break;
-        }
-		if (err==0){
-			om->b_wptr+=bytes*(frame_per_packet+1);
-			ms_queue_put(f->outputs[0],om);
-		}else {
-			if (err==-1)
-				ms_warning("speex end of stream");
-			else if (err==-2)
-				ms_warning("speex corrupted stream");
-			freemsg(om);
-		}
+		
+		/* support for multiple frame  in one RTP packet */
+ 		do{
+			om=allocb(bytes,0);
+			err=speex_decode_int(s->state,&bits,(int16_t*)om->b_wptr);
+			om->b_wptr+=bytes;
+
+			if (err==0){
+				ms_queue_put(f->outputs[0],om);
+				if (s->sample_time==0) s->sample_time=f->ticker->time;
+				s->sample_time+=20;
+				if (s->plc_count>0){
+					ms_warning("Did speex packet loss concealment during %i ms",s->plc_count*20);
+					s->plc_count=0;
+				}
+				
+			}else {
+				if (err==-1)
+					ms_warning("speex end of stream");
+				else if (err==-2)
+					ms_warning("speex corrupted stream");
+				freemsg(om);
+			}
+		}while((rem_bits= speex_bits_remaining(&bits))>10);
 		freemsg(im);
 	}
-	speex_bits_destroy(&bits);
+	if (s->plc && s->sample_time!=0 && f->ticker->time>=s->sample_time){
+		/* we should output a frame but no packet were decoded
+		 thus do packet loss concealment*/
+		om=allocb(bytes,0);
+		err=speex_decode_int(s->state,NULL,(int16_t*)om->b_wptr);
+		om->b_wptr+=bytes;
+		ms_queue_put(f->outputs[0],om);
+		
+		s->sample_time+=20;
+		s->plc_count++;
+		if (s->plc_count>=plc_max){
+			s->sample_time=0;
+		}
+	}
+	if (bits_initd) speex_bits_destroy(&bits);
 }
 
 static MSFilterMethod dec_methods[]={
 	{	MS_FILTER_SET_SAMPLE_RATE	,	dec_set_sr	},
+	{	MS_FILTER_ADD_FMTP	, dec_add_fmtp	},
 	{	0				,	NULL		}
 };
 
@@ -511,7 +555,8 @@ MSFilterDesc ms_speex_dec_desc={
 	dec_process,
 	dec_postprocess,
 	dec_uninit,
-	dec_methods
+	dec_methods,
+	MS_FILTER_IS_PUMP
 };
 
 #else
@@ -529,10 +574,12 @@ MSFilterDesc ms_speex_dec_desc={
 	.postprocess=dec_postprocess,
 	.process=dec_process,
 	.uninit=dec_uninit,
-	.methods=dec_methods
+	.methods=dec_methods,
+	.flags=MS_FILTER_IS_PUMP
 };
 
 #endif
 
 MS_FILTER_DESC_EXPORT(ms_speex_dec_desc)
 MS_FILTER_DESC_EXPORT(ms_speex_enc_desc)
+
